;
; robocop petscii
;
; released by arkanix labs in july 2020
;
; www.arkanixlabs.com
;
; code by
; aNdy (CSDb id=6404)
;
; graphics by
; w0rm (CSDb id=32190)
;
; music (from robocop game) by
; jonathan dunn (CSDb id=639)
;
; special thanks to
; iAN CooG (CSDb id=6662)
;
; this source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; the final build was compressed and squished using
; exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/
;
; questions about the source code or binaries
; can be asked on the arkanix labs forum...
; http://www.arkanixlabs.com/forum/index.php


; setup code =================================

; the name and file format for the assembled program

		!to "sourcebuild.prg",cbm

; claw in the binary data...
		
		* = $2100
		!binary "data\robocop.dat",,2

		* = $5800
		!binary "data\charset.chr"
		
		* = $6000
		!binary "data\roboset.chr"

; some label assignments	
				
scrn_ram			= $4000				; screen ram location
col_ram				= $d800				; colour ram location
col_ram_eol			= $d827				; end of line colour ram
		
; some more label assignments (zp variables)

music_speed			= $50				; 0=pal, 1=ntsc
music_tmr			= $51				; timer for music frame skip on ntsc
greets_flag			= $52				; flag to indicate whether greets mode is on!
sync				= $53				; interupt sync variable

; add a BASIC startline (SYS 16384) for auto-run after loading

		* = $0801
		!word code_entry-2
		!byte $00,$00,$9e
		!text "26624"
		!byte $00,$00,$00

; entry point for the code

		* = $6800					; hence sys 26624!
				
code_entry

; detect what machine type is being used...

start_scan
		lda $d012
chkntsc
		cmp $d012
		beq chkntsc
		bmi start_scan
		adc #$00
		lsr
		bcs isntsc
		lsr
		bcs isoldntsc
		ldx #$00					; check drean or pal
		lda #$10
chkpal
		inx
		cmp $d012
		bne chkpal
		cpx #$70
		bcc ispal
isdrean
		lda #$00
		sta music_speed				; pal speed music
		jmp detect_dun
isntsc	
		lda #$01
		sta music_speed				; ntsc speed music
		jmp detect_dun
isoldntsc
		lda #$01
		sta music_speed				; ntsc speed music
		jmp detect_dun
ispal
		lda #$00
		sta music_speed				; pal speed music

detect_dun

; stop interrupts, disable the roms and set up nmi and irq interrupt pointers	

		sei							; poke the interrupts in the eye temporarily
		
		ldx #$40
		lda #$00
clr_zp	
		sta $00,x					; clear out the zero page in case...
		inx
		bne clr_zp		
		
		lda #$35					; bin the kernal, we're flying solo cap'n
		sta $01			
				
; setup nmi

		lda #<nmi					; some nmi stuff
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int					; some irq stuff, yawn...
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d					; disable timer interrupts generated by the two CIA chips
		sta $dd0d					; kernal uses these to flash the cursor and scan
									; the keyboard, so we better stop it?

		lda $dc0d					; read these two registers to stop any CIA irqs
		lda $dd0d					; if we don't do this, a pending CIA irq might occur after we
									; finish setting up our irq - we don't want that to happen!

		lda #$00					; starting point of raster on screen ($00)
		sta $d012

		lda #$1b					; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011					; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019					; clear interupt bit
		sta $d01a					; tell vicii to generate interupt

		lda #$02					; select video bank
		sta $dd00		

		cli							; kickstart the interrupts again
				
; set greets mode to off so the colourwash running on interupt is inactive		
		
		lda #$00
		sta greets_flag
		
; end setup code =================================


; main runtime code =================================			
		
; setup the screen for the very first run

		jsr clear_screen			; clear screen with subroutine
		
; point to the uppercase ROM charset at $5800		
						
		lda #$06
		sta $d018
				
; print the intro screen ram
	
		ldx #$00					; zero x register
introram_loop						; load up whatver is in the intro
		lda intro_ram,x				; screen ram table and write to the
		sta scrn_ram,x				; screen ram
		lda intro_ram+250,x
		sta scrn_ram+250,x
		lda intro_ram+500,x
		sta scrn_ram+500,x
		lda intro_ram+750,x
		sta scrn_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne introram_loop			; all written? no? loop back!
		
; print the intro screen colour ram
			
		ldx #$00					; zero x register
introcolram_loop					; load up whatver is in the intro
		lda introcolour_ram,x		; colour ram table and write to the
		sta col_ram,x				; colour ram
		lda introcolour_ram+250,x
		sta col_ram+250,x
		lda introcolour_ram+500,x
		sta col_ram+500,x
		lda introcolour_ram+750,x
		sta col_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne introcolram_loop		; all written? no? loop back!
		
		ldy #$19					; approx 1/2 sec wait...
		jsr sync_wait_long			; call wait routine...			
		
; set the music	driver to play robocop sample

		lda #$05					; number of the sample in the file
		jsr $2100					; location of music driver			

; wait for a space press!
		
		jsr space_press				; call space press subroutine
		
; clear the intro screen

		jsr clear_screen			; clear screen with subroutine
		
		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long							
	
; print the robo petscii screen data to the, er, screen...
			
		ldx #$00					; zero x register
roboram_loop						; load up whatver is in the robo
		lda robo_ram,x				; screen ram table and write to the
		sta scrn_ram,x				; screen ram
		lda robo_ram+250,x
		sta scrn_ram+250,x
		lda robo_ram+500,x
		sta scrn_ram+500,x
		lda robo_ram+750,x
		sta scrn_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne roboram_loop			; all written? no? loop back!
		
; set the music	driver to play robocop in-game tune

		lda #$01
		jsr $2100		
		
; print up the petscii screen ram
; using a simple little 'wipe-on'		
	
		ldy #$27
		ldx #$00					; zero x register
robocol_loop						; load up whatver is in the robo
		lda robocol_ram,x			; screen ram table and write to the
		sta col_ram,x				; screen ram
		lda robocol_ram+80,x
		sta col_ram+80,x			; this block does left to right		
		lda robocol_ram+160,x		; reveal alternating lines
		sta col_ram+160,x	
		lda robocol_ram+240,x
		sta col_ram+240,x			
		lda robocol_ram+320,x
		sta col_ram+320,x				
		lda robocol_ram+400,x
		sta col_ram+400,x			
		lda robocol_ram+480,x
		sta col_ram+480,x			
		lda robocol_ram+560,x
		sta col_ram+560,x			
		lda robocol_ram+640,x
		sta col_ram+640,x			
		lda robocol_ram+720,x
		sta col_ram+720,x			
		lda robocol_ram+800,x
		sta col_ram+800,x
		lda robocol_ram+880,x
		sta col_ram+880,x						
		lda robocol_ram+960,x
		sta col_ram+960,x
		
		lda robocol_ram+40,y		; this block does right to left
		sta col_ram+40,y			; reveal alternating lines
		lda robocol_ram+120,y
		sta col_ram+120,y
		lda robocol_ram+200,y
		sta col_ram+200,y		
		lda robocol_ram+280,y
		sta col_ram+280,y				
		lda robocol_ram+360,y
		sta col_ram+360,y			
		lda robocol_ram+440,y
		sta col_ram+440,y
		lda robocol_ram+520,y
		sta col_ram+520,y		
		lda robocol_ram+600,y
		sta col_ram+600,y			
		lda robocol_ram+680,y
		sta col_ram+680,y			
		lda robocol_ram+760,y
		sta col_ram+760,y	
		lda robocol_ram+840,y
		sta col_ram+840,y			
		lda robocol_ram+920,y
		sta col_ram+920,y			
						
		tya							; we need the y register for the timer so...
		pha							; ...store y counter from above on the stack!
		
		ldy #$01					; a very tiny little wait before looping!
		jsr sync_wait_long			; call the wait routine!
		
		pla							; retrieve the y counter from the stack
		tay							; and shove back into y!
		
		inx							; increase x but....
		dey							; decrease y!
		cpx #$28					; done 40 writes?
		beq robocol_loop_dun		; all written? go down to robocol_loop_dun
		jmp robocol_loop			; no? loop back to robocol_loop!

robocol_loop_dun	
		
; wait for a space press!
		
		jsr space_press
		
; fade out the robocop petscii screen

; this works by scanning through the robocop petscii colour ram
; checking for a paritcular colour and if finding that colour,
; changing it to a darker colour to imitate a fade!

; **note** this code section could be optimised with loops or macros, 
; but is very easy to read 'expanded' like this and since memory 
; isn't an issue this will do very nicely ta!

; start with the blue background around robocop ...

		lda #$03					; we check colour ram table for cyan 
		sta check_this
		lda #$0e					; and if cyan, change to light blue
		sta change_to

		jsr do_fadeout				; do the check and change now with subroutine!
		jsr fade_delay				; a little delay to make fade visible!
		
		lda #$0e					; check for light blue
		sta check_this
		lda #$04					; changing to purple 
		sta change_to		
		
		jsr do_fadeout				; do check and change if necessary
		jsr fade_delay				; another delay...

		lda #$04					; purple check
		sta check_this
		lda #$06					; to blue!
		sta change_to			
				
		jsr do_fadeout				; etc!
		jsr fade_delay				; etc!
		
		lda #$06					; change blue...
		sta check_this
		lda #$00					; ... to black
		sta change_to			
				
		jsr do_fadeout
		jsr fade_delay
		
; now do robo himself...		

		lda #$09					; now fade robo, repeating as for blue
		sta check_this				; above, but we are checking greys instead!
		lda #$02					; also on this occasion, greys are
		sta change_to				; increased to white first for a 'flash'
									; before fading to black.  nice!
		jsr do_fadeout
		jsr fade_delay
		
		lda #$02					; check your programmers guide if
		sta check_this
		lda #$08					; you don't know your c64 colours in hex!
		sta change_to		
		
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$0b					; but you should know the c64 colours
		sta check_this
		lda #$0c					; by heart shouldn't you????  ;)
		sta change_to

		jsr do_fadeout				; no delay yet...
		
		lda #$08					; because the mouth flesh colours are
		sta check_this				; being checked the same time as
		lda #$0a					; the metal greys now, so it all
		sta change_to				; fades in sync!
		
		jsr do_fadeout
		jsr fade_delay
				
		lda #$0c
		sta check_this
		lda #$0f
		sta change_to

		jsr do_fadeout				

		lda #$0a
		sta check_this
		lda #$0f
		sta change_to			
		
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$0f
		sta check_this
		lda #$01
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$01
		sta check_this
		lda #$0f
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay	
		
		lda #$0f
		sta check_this
		lda #$0c
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay
		
		lda #$0c
		sta check_this
		lda #$0b
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$0b
		sta check_this
		lda #$00
		sta change_to
					
		jsr do_fadeout

		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long
		
; prepare the music	driver with robocop title tune

		lda #$00
		jsr $2100							
		
; clear the screen out

		jsr clear_screen			; clear screen with subroutine		
	
; point to the robocop game charset at $6000		
	
		lda #$08
		sta $d018
		
; set greets mode to on so the colourwash running on interupt is active	
		
		lda #$01
		sta greets_flag				
		
; print the greets screen title using a similar 'reveal'
; as used for the robocop petscii

		ldy #$27					; y register set to $27...
		ldx #$00					; ...and zero x register
greets_title_loop					; load up whatver is in the greets
		lda greets_ram_title,x		; screen ram title table and write to the
		sta scrn_ram,x				; screen ram

		lda greets_ram_title+40,y	; reveal right to left
		sta scrn_ram+40,y

		tya							; we also need the 'y' register for the delay
		pha							; so put 'y' into 'a' and store on the stack!
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long
									; the delay routine has finished...	
		pla							; so pull the value stored on the stack into 'a' 
		tay							; and put back into 'y'!  simple!
		
		inx							; increase 'x'
		dey							; decrease 'y'
		cpx #$28					; is 'x' $28?
		bne greets_title_loop		; no?  repeat loop!
									; yes?  then do a small...
		ldy #$19					; ...1/2 sec wait!
		jsr sync_wait_long			; call wait subroutine
		
; print the group greets names in a typewriter style,
; one character at a time...
		
		lda #$50					; the group names for the greets screen 
		sta $fd						; will start typing at $4050
		lda #$40
		sta $fe		

		lda #<greets_ram_names		; start of the greets names data table (lo)
		sta $fb
		lda #>greets_ram_names		; end of the greets names data table (hi)
		sta $fc
	
		ldx #$00					; zero x and y
		ldy #$00
print_greets_names
		lda #$62					; the small fake cursor char!
		sta ($fd),y					; plot to current screen position
		tya
		pha	
		ldy #$03					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!
		pla
		tay
		
		lda #$63					; the large fake cursor char!
		sta ($fd),y					; plot to the same screen position,
		tya							; overwriting the small cursor
		pha	
		ldy #$01					; another little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!
		pla
		tay							

		lda ($fb),y					; now the next letter from the data table	
		sta ($fd),y					; is printed to current screen position
		iny							; overwriting the large cursor!
									; this should look like a cursor
		tya							; typing on the screen!
		pha		
		
		ldy #$01					; yet another wait to make things visible
		jsr sync_wait_long
		
		pla
		tay	
		
		bne print_greets_names		; keep printing until we run out of
									; data from the greets names data
		inc $fc						; table!
		inc $fe		
		inx
		cpx #$04
		bne print_greets_names
		
; wait for a space press!
		
		jsr space_press
		
; fade out greets screen

		lda #$05					; same principle as fading the main
		sta check_this				; robocop petscii screen, so see the
		lda #$0d					; code above for descriptions!
		sta change_to				; only difference?  checking for greens!
					
		jsr do_greetsfade
		jsr fade_delay
		
		lda #$0d
		sta check_this
		lda #$01
		sta change_to
					
		jsr do_greetsfade
		jsr fade_delay
				
		lda #$01
		sta check_this
		lda #$0f
		sta change_to
					
		jsr do_greetsfade
		jsr fade_delay	
		
		lda #$0f
		sta check_this
		lda #$0c
		sta change_to
					
		jsr do_greetsfade
		jsr fade_delay
		
		lda #$0c
		sta check_this
		lda #$0b
		sta change_to
					
		jsr do_greetsfade
		jsr fade_delay		
		
		lda #$0b
		sta check_this
		lda #$00
		sta change_to
					
		jsr do_greetsfade

		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long

; clear the screen out

		jsr clear_screen			; clear screen with subroutine
		
; set greets mode to off so the colourwash running on interupt is inactive	
		
		lda #$00
		sta greets_flag
		
; prepare the music	driver with robocop game over tune

		lda #$04
		jsr $2100								
				
; print final 'thank you' message

		ldx #$00
		lda #$05					
coopcol_loop						; make the single line we want the thank you
		sta col_ram+480,x			; message on all green in the colour ram!
		inx
		cpx #$28
		bne coopcol_loop

		ldx #$00					; now print the thank you message!
coop_loop
		lda #$62					; fake cursors again to type out the
		sta scrn_ram+480,x			; thank you message!

		ldy #$03					; a little wait
		jsr sync_wait_long
		
		lda #$63					; more fake cursorage!
		sta scrn_ram+480,x

		ldy #$01					; a little wait
		jsr sync_wait_long

		lda final_mess,x			; grab the thanks message from this data table!
		sta scrn_ram+480,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long
				
		inx
		cpx #$28					; done 40 writes?
		bne coop_loop				; all written? no? loop back!
				
		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long										
	
; now reset some registers...

		sei							; poke the interrupts in the eye again
		
		lda #$37					; let basic and kernal out of their cage
		sta $01

		lda #$00
		sta $d011
		sta $d020
		sta $d021
		sta $d418

; and finally reset the C64 using kernal routine

		jmp $fce2
		
; end main runtime code =================================					
												

; irq interrupt =========================================

int
		pha  						; preserve some values on the stack
		txa
		pha
		tya
		pha

		lda $d019
		and #$01
		sta $d019

; play some music with cheap 'hack' to slow for ntsc

		lda music_speed				; what machine is being used
		cmp #$00					; PAL speed?
		beq call_music_driver		; yes? play the music!
									; no?
		ldx music_tmr				; load music timer
		inx							; increase it
		cpx #$06					; is it 6?
		bne	music_play				; no? play music!
									; yes?
		ldx #$00					; reset the timer
		stx music_tmr				; then skip playing
									; the music on this occasion
		jmp music_stuff_dun			; to slow it for ntsc!

music_play
		stx	music_tmr
		
call_music_driver
		jsr $254f					; play the music!
		
music_stuff_dun

; are we on the greetings screen? should the colourwash be active?

		lda greets_flag				; check if greets flag is on...
		cmp #$01					; is it '1'?
		bne skip_colourwash_call	; no?  skip down to skip_colourwash_call
									; yes?
		jsr greets_colourwash		; run the colourwash subroutine!
		
skip_colourwash_call

		lda #$01					; set the sync flag to '1'		
		sta sync					; so the main code runs!			
		
		pla							; pull any preserved values from the
		tay							; stack and put into respective
		pla							; resgisters
		tax
		pla
nmi		rti

; end irq interrupt =============================


; subroutines ===================================


; clear the screen!

clear_screen
		lda #$00					; we'll be wanting a black border
		sta $d020					; and background then will we?
		sta $d021					; yup, though so!
		tax							; tranfer the zero in 'a' to 'x'
clsloop
		lda #$20					; code for a blank 'space'
		sta scrn_ram,x				; clear all lines on the screen!
		sta scrn_ram+250,x
		sta scrn_ram+500,x
		sta scrn_ram+750,x
		lda #$00					; hex colour code for black!
		sta col_ram,x				; all colour ram to black!
		sta col_ram+250,x
		sta col_ram+500,x
		sta col_ram+750,x	
		inx
		cpx #$fa
		bne clsloop
		
		rts		

; space press detect subroutine -----------------------------

space_press
		lda $dc01					; load $dc01 to test...
		cmp #$ef					; space key pressed...
		bne space_press				; not pressed? loop!
									; is pressed?  call...
		jsr key_debounce			; ...the debounce routine!

		rts
		
; debounce subroutines for keyboard -------------------

key_debounce		
		lda $dc01					; is there still a keypress?
		cmp #$ff					; an idiot is still pressing something???
		bne key_debounce			; lock them in a loop till they stop!!
		
		rts
		
; fade screen out subroutine for robo screen -------------------

do_fadeout
		ldx #$00
fade_loop
		lda robocol_ram,x			; scan the robo colour ram table
		cmp check_this				; check for this colour
		bne block2					; if not that colour, check next block
		lda change_to				; is colour matches, change the colour
		sta robocol_ram,x			; and store in the colour ram table 
		sta col_ram,x				; and to the screen!
block2		
		lda robocol_ram+250,x		; same as above, but for second block
		cmp check_this				; of screen.
		bne block3
		lda change_to
		sta robocol_ram+250,x
		sta col_ram+250,x
block3
		lda robocol_ram+500,x		; etc, etc!
		cmp check_this
		bne block4
		lda change_to
		sta robocol_ram+500,x
		sta col_ram+500,x
block4
		lda robocol_ram+750,x		; more checking here!!!!
		cmp check_this
		bne chkloop
		lda change_to
		sta robocol_ram+750,x
		sta col_ram+750,x
chkloop
		inx
		cpx #$fa					; each block has 250 checks!
		bne fade_loop
		
		rts
		
; fade screen out subroutine for greets screen -------------------

do_greetsfade
		ldx #$00
greetsfade_loop
		lda colourwash_table1,x		; same principle as robo fade above!
		cmp check_this
		bne checktable2
		lda change_to
		sta colourwash_table1,x
checktable2
		lda colourwash_table2,x
		cmp check_this
		bne checktablesdun
		lda change_to
		sta colourwash_table2,x	
checktablesdun		
		inx
		cpx #$28		
		bne greetsfade_loop
		
		rts		

; delay subroutine for screen fade --------------------		
				
fade_delay				
		ldy #$03					; a little wait before returning
		jsr sync_wait_long
		
		rts
		
; colourwash subroutine for greets screen --------------------

; note: colourwash is run on interupt (called from the irq code)

greets_colourwash
										; colourwash right to left
		lda colourwash_table1+$00		; store the first value in colourwash1 table
		sta colourwash_temp				; into the temp store
		ldx #$00
do_cycle_rl
		lda colourwash_table1+$01,x		; now copy each value in the wash table 1
		sta colourwash_table1+$00,x		; one place to the left
		lda colourwash_table1,x			; and store in the table!
		sta col_ram,x					; then copy to every other line
		sta col_ram+40,x				; on the screen (colour ram)
		sta col_ram+120,x
		sta col_ram+200,x
		sta col_ram+280,x
		sta col_ram+360,x
		sta col_ram+440,x
		sta col_ram+520,x
		sta col_ram+600,x
		sta col_ram+680,x
		sta col_ram+760,x
		sta col_ram+840,x
		sta col_ram+920,x
		inx
		cpx #$28						; repeat above for whole 'line'
		bne do_cycle_rl
		lda colourwash_temp				; then, finally, copy the temp store
		sta colourwash_table1+$28		; to the last value to 'wrap' the colours!	

										; now colourwash left to right!				
		lda colourwash_table2+$28		; same as above, but in reverse to
		sta colourwash_temp				; colour wash the other way!
		ldx #$28
do_cycle_lr
		lda colourwash_table2-$01,x
		sta colourwash_table2+$00,x
		lda colourwash_table2,x
		sta col_ram_eol+40,x
		sta col_ram_eol+120,x
		sta col_ram_eol+200,x
		sta col_ram_eol+280,x
		sta col_ram_eol+360,x
		sta col_ram_eol+440,x
		sta col_ram_eol+520,x
		sta col_ram_eol+600,x
		sta col_ram_eol+680,x
		sta col_ram_eol+760,x
		sta col_ram_eol+840,x
		sta col_ram_eol+920,x											
		dex
		bne do_cycle_lr
		lda colourwash_temp		
		sta colourwash_table2+$00
		
		rts
		
; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait								; wait for sync update in irq code!
		lda #$00						; waits until the sync flag is
		sta sync						; set at the end of the interupt
sw_loop									; code further down.
		cmp sync						; no code in the main loop above
		beq sw_loop						; is executed until the interupt
										; has run it's course!
		rts

; a sync wait delay subroutine ---------------------------------- 		
		
sync_wait_long							; loop around here and above until			
		jsr sync_wait					; 'y' (loaded elsewhere in the code
		dey								; before coming here) is zero
		bne sync_wait_long

		rts				
			   	
; end subroutines ===============================


; data tables here! ==========================

; temp stores for robo screen fade subroutine

check_this	!byte $00
change_to	!byte $00

; intro screen ram data

intro_ram
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$01,$0E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$01,$20,$12,$20,$0B,$20,$01,$20,$0E,$20,$09,$20,$18,$20,$20,$20,$0C,$20,$01,$20,$02,$20,$13,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$10,$12,$0F,$04,$15,$03,$14,$09,$0F,$0E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$6F,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$6F,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$AE,$E8,$E8,$A5,$65,$6F,$6F,$20,$6F,$6F,$6F,$20,$20,$6F,$6F,$20,$E9,$AE,$E8,$E8,$69,$6F,$6F,$20,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$DC,$EC,$FE,$69,$E9,$AE,$E8,$DF,$AE,$E8,$E8,$DF,$E9,$AE,$E8,$DF,$AE,$EC,$E2,$E2,$E9,$AE,$E8,$DF,$AE,$E8,$E8,$DF,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$DC,$FE,$A2,$DF,$DC,$EC,$FB,$E8,$DC,$EC,$E9,$69,$DC,$EC,$FB,$E8,$DC,$5C,$20,$20,$DC,$EC,$FB,$E8,$DC,$EC,$E9,$69,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$AE,$E8,$E8,$A2,$DC,$FC,$FE,$A5,$DC,$E8,$ED,$FC,$DC,$FC,$FE,$A5,$DC,$FC,$68,$62,$E8,$FC,$FE,$A5,$DC,$BE,$77,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$E8,$EC,$FB,$A5,$5F,$E8,$A5,$69,$E8,$FC,$FE,$EC,$5F,$E8,$A5,$69,$5F,$AE,$E8,$A5,$CD,$E8,$A5,$69,$E8,$61,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$7C,$E2,$7E,$7C,$E2,$20,$77,$77,$20,$77,$77,$77,$20,$20,$77,$77,$20,$20,$78,$E2,$E2,$7E,$77,$77,$20,$77,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$3A,$20,$10,$20,$3A,$20,$05,$20,$3A,$20,$14,$20,$3A,$20,$13,$20,$3A,$20,$03,$20,$3A,$20,$09,$20,$3A,$20,$09,$20,$3A,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$10,$12,$09,$0D,$05,$20,$10,$05,$12,$13,$0F,$0E,$0E,$05,$0C,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$31,$3A,$20,$17,$30,$12,$0D,$2E,$2E,$2E,$20,$13,$05,$12,$16,$09,$0E,$07,$20,$15,$10,$20,$14,$08,$05,$20,$07,$12,$01,$10,$08,$09,$03,$13,$20,$20,$20,$20
!byte $20,$20,$32,$3A,$20,$04,$15,$0E,$0E,$2E,$2E,$2E,$20,$03,$0F,$0E,$04,$15,$03,$14,$09,$0E,$07,$20,$14,$08,$05,$20,$09,$0E,$13,$14,$12,$15,$0D,$05,$0E,$14,$13,$20
!byte $20,$20,$33,$3A,$20,$01,$0E,$04,$19,$2E,$2E,$2E,$20,$15,$10,$0C,$0F,$01,$04,$09,$0E,$07,$20,$14,$08,$05,$20,$03,$0F,$04,$05,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$34,$3A,$20,$03,$0F,$0F,$07,$2E,$2E,$2E,$20,$1B,$03,$0C,$01,$13,$13,$09,$06,$09,$05,$04,$20,$12,$13,$09,$04,$20,$09,$0E,$06,$0F,$1D,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

introcolour_ram
!byte $01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$05,$05,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0F,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$05,$00,$05,$00,$05,$00,$05,$00,$05,$00,$05,$00,$05,$00,$05,$00,$00,$00,$05,$00,$05,$00,$05,$00,$05,$00,$05,$05,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$0F,$0F,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$05,$00,$00,$00,$00,$00,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$05,$0B,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$0F,$0F,$01,$0F,$0F,$0F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$01,$0F,$0F,$0F,$0B,$00,$0F,$00,$00,$00,$00,$0F,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$01,$0C,$0C,$0C,$0C,$0B,$01,$0F,$00,$01,$0F,$0F,$00,$00,$01,$0F,$00,$0F,$0C,$0C,$0C,$0C,$01,$0F,$00,$01,$0F,$0F,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$01,$0C,$0B,$0F,$0C,$0F,$0C,$0C,$0B,$0C,$0C,$0C,$0B,$0F,$0C,$0C,$0B,$0C,$0B,$0B,$0B,$0F,$0C,$0C,$0B,$0C,$0C,$0C,$0C,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0C,$0F,$0C,$0B,$0C,$0B,$0C,$0C,$0C,$0B,$0F,$0C,$0C,$0B,$0C,$0C,$0C,$0B,$0C,$0C,$0C,$0B,$0C,$0C,$0C,$0B,$0F,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0C,$0C,$0C,$0C,$0C,$0B,$0F,$0B,$0C,$0C,$0C,$0B,$0C,$0B,$0F,$0B,$0C,$0B,$0C,$0F,$0C,$0B,$0F,$0B,$0C,$0B,$0B,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0F,$0C,$0B,$0F,$0B,$0C,$0C,$0B,$0B,$0C,$0B,$0F,$0B,$0C,$0C,$0B,$0B,$0C,$0C,$0C,$0B,$0C,$0C,$0B,$0B,$0C,$0B,$0C,$0B,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$0C,$0B,$0B,$0C,$0B,$00,$0B,$0B,$00,$0B,$0B,$0B,$0B,$00,$0B,$0B,$00,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$0B,$0B,$0B,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$05,$05,$05,$00,$0D,$00,$05,$0C,$0D,$00,$05,$00,$0D,$0F,$05,$00,$0D,$00,$05,$0C,$0D,$00,$05,$00,$0D,$0B,$05,$00,$0D,$00,$05,$05,$05,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$05,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$05,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$05,$05,$05,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$05,$05,$0C,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$05,$05,$00,$05,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$00,$0B,$00,$00
!byte $00,$00,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$05,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00
!byte $00,$00,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$05,$05,$05,$00,$05,$05,$05,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$05,$05,$00,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$05,$00,$05,$05,$05,$05,$05,$00,$00,$00,$00,$00
!byte $01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01

; petscii screen ram data

robo_ram
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$22,$2E,$68,$E6,$66,$68,$20,$56,$5C,$E6,$68,$66,$5C,$E6,$68,$2E,$20,$2E,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$25,$27,$7E,$68,$25,$66,$DC,$66,$2C,$66,$66,$A3,$66,$DC,$E6,$A3,$66,$56,$5C,$2C,$7F,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$66,$23,$6C,$7E,$1C,$A5,$66,$DC,$E8,$E6,$5C,$22,$66,$66,$E8,$DC,$DC,$E6,$A3,$66,$26,$5C,$2C,$7F,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$E6,$6C,$20,$68,$DC,$DC,$25,$66,$DC,$66,$E6,$20,$23,$DC,$66,$66,$E8,$56,$DC,$E8,$66,$58,$5C,$3A,$21,$21,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$27,$61,$1C,$DC,$DC,$66,$66,$DC,$66,$E8,$66,$5C,$3E,$66,$DC,$E8,$DC,$66,$E8,$DC,$DC,$A3,$5C,$2E,$E1,$20,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$5C,$FF,$68,$DC,$E8,$DC,$25,$DC,$E8,$56,$5C,$E6,$5C,$2E,$68,$66,$66,$E8,$DC,$E6,$E8,$66,$DC,$58,$3B,$68,$5C,$21,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$23,$20,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$76,$8F,$BA,$83,$DC,$90,$56,$DC,$DC,$DC,$E6,$A3,$E6,$20,$68,$DC,$A3,$66,$DC,$56,$DC,$A3,$66,$E6,$20,$E6,$DC,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$27,$E8,$66,$66,$E8,$DC,$E6,$DC,$E8,$56,$66,$26,$66,$21,$5C,$23,$DC,$66,$BE,$E6,$E8,$DC,$E8,$66,$21,$E6,$66,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$21,$FF,$E2,$7F,$7F,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$1B,$FF,$E2,$7F,$7F,$DC,$66,$9B,$66,$A3,$E8,$E6,$66,$2C,$68,$E6,$E6,$66,$D6,$66,$E6,$E8,$E6,$21,$2C,$E6,$E6,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$76,$E1,$D7,$E1,$E1,$DC,$E8,$25,$63,$63,$63,$63,$63,$20,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$77,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$76,$7C,$C0,$E1,$E1,$62,$62,$68,$64,$64,$64,$64,$64,$20,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$6F,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$3A,$7F,$68,$FF,$FF,$DC,$DC,$58,$E8,$DC,$E6,$D6,$E6,$20,$68,$3E,$E6,$DC,$E6,$DC,$E6,$E8,$E8,$5C,$2C,$E6,$66,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$5C,$7B,$62,$FF,$FE,$E8,$DC,$E8,$23,$E8,$E8,$E6,$66,$20,$E6,$66,$E8,$D6,$DC,$66,$E8,$66,$E6,$20,$E6,$66,$E6,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$5C,$56,$C0,$C0,$C0,$AD,$E8,$A5,$E8,$56,$DC,$E8,$5C,$21,$68,$56,$66,$E8,$E6,$E8,$DC,$E6,$2C,$21,$66,$E6,$E6,$7E,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$5C,$1B,$E6,$66,$5C,$E6,$DC,$DC,$E8,$DC,$E6,$BB,$AE,$E6,$E8,$DC,$E8,$E4,$E4,$E7,$E4,$E4,$E8,$E6,$BA,$23,$FF,$2E,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$20,$5C,$5C,$20,$66,$7F,$7C,$DC,$E8,$DC,$E8,$E6,$AD,$9B,$A8,$FE,$EF,$E4,$EC,$F9,$E4,$FC,$A9,$E8,$66,$5C,$25,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$5C,$20,$25,$20,$20,$20,$7F,$20,$FB,$DC,$E8,$E8,$DC,$AE,$A0,$FC,$FB,$AE,$E8,$E8,$EC,$FE,$BB,$DE,$A5,$61,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$5C,$21,$22,$20,$20,$20,$20,$7F,$20,$FB,$DC,$E8,$DC,$BA,$DC,$E8,$FC,$F8,$F8,$F8,$FE,$A5,$E8,$E8,$E8,$7B,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$22,$27,$20,$20,$3A,$23,$20,$20,$20,$20,$20,$6F,$63,$77,$78,$78,$77,$63,$2E,$68,$66,$A3,$66,$E6,$68,$20,$DC,$5C,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $22,$27,$64,$2E,$68,$46,$40,$20,$20,$5C,$22,$5C,$20,$20,$20,$20,$20,$45,$44,$43,$43,$44,$45,$77,$77,$63,$63,$63,$77,$FB,$A3,$E8,$7E,$21,$22,$66,$E6,$66,$E6,$66
!byte $45,$63,$2E,$67,$27,$20,$2E,$20,$20,$20,$3A,$7C,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$2C,$E6,$66,$7E,$40,$46,$52,$22,$64,$27,$22
!byte $68,$66,$2E,$5C,$65,$20,$2E,$20,$20,$2E,$20,$20,$22,$4D,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$64,$64,$2C,$63,$FE,$E6,$22,$20,$2E,$20,$20,$20,$20,$20,$63
!byte $5C,$22,$66,$2E,$7F,$20,$20,$2E,$20,$20,$2E,$20,$20,$20,$45,$44,$43,$52,$2E,$20,$20,$20,$20,$64,$2E,$2C,$52,$46,$E2,$22,$20,$20,$2E,$20,$20,$20,$17,$30,$12,$0D
		
; main colour ram data

robocol_ram
!byte $03,$03,$03,$0E,$0E,$0E,$04,$04,$06,$06,$06,$06,$0B,$0C,$0C,$0C,$0B,$0B,$0B,$0B,$0C,$0F,$0B,$0C,$0B,$0B,$0B,$0B,$0B,$06,$06,$06,$04,$04,$04,$0E,$0E,$0E,$03,$03
!byte $03,$03,$0E,$0E,$0E,$04,$04,$06,$06,$06,$06,$0B,$0B,$0C,$01,$0F,$0C,$0B,$0B,$0C,$0C,$0C,$0F,$01,$0F,$0C,$0B,$0B,$0B,$0B,$06,$06,$06,$04,$04,$04,$0E,$0E,$0E,$03
!byte $03,$0E,$0E,$0E,$04,$04,$06,$06,$06,$0B,$0B,$0B,$0C,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0C,$0C,$0F,$0F,$01,$0F,$0C,$0B,$0B,$0B,$0B,$06,$06,$06,$04,$04,$04,$0E,$0E,$0E
!byte $0E,$0E,$0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0B,$0C,$0F,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0B,$06,$06,$06,$04,$04,$0E,$0E,$03
!byte $03,$0E,$0E,$04,$04,$06,$06,$06,$0B,$0B,$0C,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0B,$0B,$0C,$0C,$0F,$01,$0F,$0F,$0C,$0C,$0B,$0B,$0B,$00,$06,$06,$04,$04,$04,$0E,$0E
!byte $0E,$0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0C,$0B,$0B,$0B,$0B,$0B,$0B,$0C,$0C,$0F,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0B,$06,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0C,$0B,$0B,$0B,$0B,$00,$0B,$0C,$0C,$0F,$01,$01,$01,$0F,$0C,$0B,$00,$0B,$0B,$00,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0C,$0F,$0F,$01,$0F,$0C,$0C,$0B,$00,$0B,$0C,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0C,$0C,$0F,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0C,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0B,$0C,$0F,$01,$0F,$0F,$0C,$0B,$0B,$0B,$0B,$0C,$0C,$0F,$0F,$01,$0F,$0F,$0C,$0B,$00,$0B,$0C,$0F,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0C,$01,$0C,$0B,$0C,$0F,$01,$0F,$0C,$0C,$0B,$0B,$0B,$0B,$0B,$0C,$0F,$0F,$01,$0F,$0F,$0C,$0B,$0B,$0B,$0C,$0F,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0C,$0B,$0F,$0F,$0B,$0C,$0F,$01,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0C,$0F,$01,$0B,$0C,$0F,$01,$0B,$0B,$0B,$0B,$0B,$01,$0B,$0B,$0B,$0B,$0B,$0B,$0C,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$0B,$0C,$0F,$0F,$0B,$0C,$0F,$01,$0F,$0C,$0C,$0B,$0B,$00,$0B,$0B,$0B,$0B,$0B,$0C,$0F,$0C,$0B,$0B,$0B,$0B,$0C,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$06,$0B,$0B,$0B,$0B,$0C,$0C,$0F,$01,$0F,$0C,$0B,$0B,$00,$0B,$0B,$0B,$0B,$0C,$0F,$0C,$0B,$0B,$0B,$0B,$0C,$0C,$0B,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$04,$04,$06,$06,$06,$0B,$0B,$0B,$0C,$0C,$0C,$0C,$0F,$01,$0F,$0C,$0B,$0B,$0B,$0B,$0B,$0B,$0F,$0C,$0B,$0B,$0B,$0B,$0C,$0C,$0B,$0B,$06,$06,$04,$04,$0E,$0E
!byte $03,$0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0C,$0B,$09,$02,$08,$0A,$0A,$0A,$0A,$08,$0A,$0A,$0A,$0A,$08,$08,$0A,$0A,$0A,$08,$02,$09,$06,$06,$06,$04,$04,$0E,$0E
!byte $0E,$0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0C,$0B,$0B,$09,$09,$02,$08,$08,$0A,$0A,$0A,$0A,$02,$02,$02,$02,$02,$02,$02,$0A,$08,$02,$0B,$06,$06,$04,$04,$04,$0E,$0E
!byte $03,$0E,$0E,$04,$04,$06,$06,$06,$0B,$0B,$0C,$0B,$00,$0B,$00,$09,$02,$02,$08,$0A,$0A,$0A,$0A,$02,$02,$02,$02,$02,$0A,$08,$08,$02,$0B,$06,$06,$04,$04,$04,$0E,$03
!byte $03,$03,$0E,$0E,$04,$04,$06,$06,$0B,$0B,$0B,$0B,$0B,$00,$0B,$00,$09,$09,$02,$08,$02,$08,$0A,$0A,$08,$08,$08,$0A,$08,$08,$02,$09,$0B,$06,$04,$04,$04,$0E,$0E,$0E
!byte $03,$03,$03,$0E,$04,$04,$06,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$00,$0B,$09,$09,$09,$09,$09,$09,$0B,$0B,$0C,$0C,$0C,$0B,$0B,$00,$0B,$0B,$06,$04,$04,$04,$0E,$0E,$03
!byte $03,$03,$0B,$0B,$0B,$0B,$0B,$0E,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0C,$0B,$0B,$06,$04,$04,$0E,$0E,$03,$03
!byte $0B,$0B,$0B,$0B,$0B,$03,$0B,$0B,$06,$0B,$0B,$0B,$0B,$00,$0B,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$0B,$0C,$0B,$0B,$0B,$0B,$0B,$0E,$0B,$03,$03
!byte $0B,$0B,$0B,$0B,$0B,$0E,$0B,$06,$0B,$0B,$06,$06,$0B,$0B,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$0B,$00,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$0B,$0B,$00,$00,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$0B,$04,$0B,$06,$06,$0B,$06,$06,$06,$0B,$0B,$0B,$0B,$0B,$00,$00,$00,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$0B,$0B,$00,$00,$0B,$0B,$0B,$0B,$0B

; greets screen ram data

greets_ram_title
!byte $01,$02,$03,$04,$05,$06,$01,$02,$07,$08,$09,$0B,$0C,$20,$0D,$20,$01,$02,$0F,$10,$11,$12,$20,$13,$14,$03,$04,$15,$16,$15,$16,$17,$18,$09,$07,$08,$13,$14,$11,$12
!byte $21,$22,$23,$24,$25,$26,$21,$22,$27,$28,$29,$2B,$2C,$20,$2D,$2E,$21,$22,$2F,$30,$31,$32,$20,$33,$34,$23,$24,$35,$36,$35,$36,$20,$38,$29,$27,$28,$33,$34,$31,$32

greets_ram_names
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $9B,$81,$82,$93,$85,$8E,$83,$85,$9B,$9B,$9B,$9B,$81,$82,$99,$93,$93,$20,$83,$8F,$8E,$8E,$85,$83,$94,$89,$8F,$8E,$9B,$9B,$9B,$81,$92,$94,$93,$94,$81,$94,$85,$9B
!byte $81,$94,$85,$20,$82,$89,$94,$9B,$9B,$81,$94,$8C,$81,$8E,$94,$89,$93,$9B,$9B,$82,$8F,$8F,$9A,$85,$20,$84,$85,$93,$89,$87,$8E,$9B,$9B,$83,$81,$8D,$85,$8C,$8F,$94
!byte $83,$85,$8E,$93,$8F,$92,$20,$84,$85,$93,$89,$87,$8E,$9B,$9B,$83,$88,$8F,$92,$95,$93,$9B,$9B,$83,$88,$92,$8F,$8D,$85,$9B,$9B,$83,$8E,$83,$84,$9B,$9B,$83,$90,$95
!byte $9B,$83,$8F,$93,$89,$8E,$85,$9B,$9B,$83,$92,$85,$93,$83,$85,$8E,$94,$9B,$9B,$83,$92,$85,$93,$94,$9B,$9B,$83,$8F,$96,$85,$92,$94,$20,$82,$89,$94,$8F,$90,$93,$9B
!byte $9B,$84,$85,$86,$85,$8E,$83,$85,$20,$86,$8F,$92,$83,$85,$9B,$9B,$9B,$84,$85,$8B,$81,$84,$85,$8E,$83,$85,$9B,$9B,$84,$85,$93,$89,$92,$85,$9B,$9B,$84,$81,$83,$9B
!byte $9B,$84,$8D,$81,$87,$89,$83,$9B,$9B,$85,$98,$83,$8C,$95,$93,$89,$96,$85,$20,$8F,$8E,$9B,$9B,$9B,$86,$81,$89,$92,$8C,$89,$87,$88,$94,$9B,$9B,$86,$9D,$83,$87,$9B
!byte $86,$89,$92,$85,$9B,$9B,$86,$8C,$81,$94,$9C,$9B,$9B,$86,$8F,$83,$95,$93,$9B,$9B,$86,$92,$85,$8E,$83,$88,$9B,$94,$8F,$95,$83,$88,$9B,$9B,$88,$89,$94,$8D,$85,$8E
!byte $88,$8F,$81,$98,$85,$92,$93,$9B,$9B,$9B,$88,$8F,$8B,$95,$94,$8F,$20,$86,$8F,$92,$83,$85,$9B,$9B,$9B,$9B,$8C,$85,$87,$89,$8F,$8E,$20,$8F,$86,$20,$84,$8F,$8F,$8D
!byte $9B,$8D,$81,$8E,$89,$81,$83,$93,$20,$8F,$86,$20,$8E,$8F,$89,$93,$85,$9B,$9B,$9B,$9B,$8D,$81,$99,$84,$81,$99,$9B,$9B,$9B,$9B,$8D,$85,$81,$8E,$94,$85,$81,$8D,$9B
!byte $9B,$9B,$8D,$85,$94,$81,$8C,$96,$8F,$94,$85,$9B,$9B,$8E,$8F,$8E,$81,$8D,$85,$9B,$9B,$8E,$8F,$93,$94,$81,$8C,$87,$89,$81,$9B,$9B,$8E,$95,$81,$8E,$83,$85,$9B,$9B
!byte $9B,$8F,$86,$86,$85,$8E,$83,$85,$9B,$9B,$8F,$8E,$93,$8C,$81,$95,$87,$88,$94,$9B,$9B,$8F,$92,$82,$9B,$9B,$8F,$98,$99,$92,$8F,$8E,$9B,$9B,$90,$81,$84,$95,$81,$9B
!byte $9B,$9B,$9B,$90,$85,$92,$86,$8F,$92,$8D,$85,$92,$93,$9B,$9B,$90,$8C,$95,$93,$88,$9B,$9B,$90,$90,$83,$93,$9B,$9B,$90,$93,$99,$94,$92,$8F,$8E,$89,$8B,$9B,$9B,$9B
!byte $92,$85,$90,$94,$89,$8C,$89,$81,$9B,$9B,$92,$85,$93,$8F,$95,$92,$83,$85,$9B,$9B,$92,$87,$83,$84,$9B,$9B,$93,$85,$83,$95,$92,$85,$9B,$9B,$93,$88,$81,$90,$85,$20
!byte $9B,$9B,$93,$89,$84,$85,$20,$82,$9B,$9B,$9B,$93,$89,$8E,$87,$95,$8C,$81,$92,$9B,$9B,$93,$8C,$81,$93,$88,$9B,$9B,$93,$8C,$89,$90,$93,$94,$92,$85,$81,$8D,$9B,$9B
!byte $9B,$93,$95,$83,$83,$85,$93,$93,$20,$81,$8E,$84,$20,$94,$92,$83,$9B,$9B,$93,$94,$99,$8C,$85,$9B,$9B,$93,$95,$89,$83,$99,$8F,$20,$89,$8E,$84,$95,$93,$94,$9B,$9B
!byte $9B,$9B,$9B,$9B,$94,$81,$92,$91,$95,$81,$92,$94,$9B,$9B,$9B,$94,$85,$8D,$90,$85,$93,$94,$9B,$9B,$9B,$94,$85,$8B,$9B,$9B,$9B,$94,$92,$89,$81,$84,$9B,$9B,$9B,$9B
!byte $94,$92,$89,$93,$94,$81,$92,$20,$81,$8E,$84,$20,$92,$85,$84,$20,$93,$85,$83,$94,$8F,$92,$9B,$9B,$9B,$96,$89,$92,$95,$9A,$9B,$9B,$9B,$96,$89,$93,$89,$8F,$8E,$9B
!byte $9B,$97,$8F,$97,$9B,$9B,$9B,$97,$92,$81,$89,$94,$88,$20,$84,$85,$93,$89,$87,$8E,$93,$9B,$9B,$9B,$98,$85,$8E,$8F,$8E,$9B,$9B,$9B,$98,$85,$8E,$94,$81,$98,$9B,$9B
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$9B,$9B,$9B,$81,$8E,$84,$20,$81,$8E,$99,$8F,$8E,$85,$20,$85,$8C,$93,$85,$20,$97,$85,$20,$86,$8F,$92,$87,$8F,$94,$9E,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$97,$20,$97,$20,$97,$20,$9B,$20,$81,$20,$92,$20,$8B,$20,$81,$20,$8E,$20,$89,$20,$98,$20,$8C,$20,$81,$20,$82,$20,$93,$20,$9B,$20,$83,$20,$8F,$20,$8D,$20,$20

; final thank you message data

final_mess
!byte $20,$20,$20,$20,$94,$88,$81,$8E,$8B,$20,$99,$8F,$95,$20,$86,$8F,$92,$20,$99,$8F,$95,$92,$20,$83,$8F,$8F,$90,$85,$92,$81,$94,$89,$8F,$8E,$9B,$20,$20,$20,$20,$20

; colour wash tables for greetings screen

colourwash_table1
		!byte $05,$05,$05,$05,$05
		!byte $0d,$05,$0d,$0d,$0d
		!byte $0d,$0d,$01,$0d,$01
		!byte $01,$0d,$01,$01,$01
		!byte $01,$01,$0d,$01,$01
		!byte $01,$0d,$01,$0d,$0d
		!byte $0d,$0d,$0d,$05,$0d
		!byte $05,$05,$05,$05,$05
		
colourwash_table2
		!byte $05,$05,$05,$05,$05
		!byte $0d,$05,$0d,$0d,$0d
		!byte $0d,$0d,$01,$0d,$01
		!byte $01,$0d,$01,$01,$01
		!byte $01,$01,$0d,$01,$01
		!byte $01,$0d,$01,$0d,$0d
		!byte $0d,$0d,$0d,$05,$0d
		!byte $05,$05,$05,$05,$05

; temp store for colour wash effect		
			
colourwash_temp
		!byte $00	